@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * This code is free software; you can redistribute it and/or modify it
@@ -24,14 +24,14 @@
  */
 package org.graalvm.visualvm.heapviewer.truffle.lang.r;
 
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.List;
 import org.graalvm.visualvm.heapviewer.model.HeapViewerNode;
 import org.graalvm.visualvm.heapviewer.truffle.TruffleFrame;
 import org.graalvm.visualvm.heapviewer.truffle.TruffleObject;
 import org.graalvm.visualvm.heapviewer.truffle.TruffleObjectPropertyProvider;
 import org.graalvm.visualvm.heapviewer.truffle.dynamicobject.DynamicObject;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.List;
 import org.graalvm.visualvm.heapviewer.utils.HeapOperations;
 import org.graalvm.visualvm.lib.jfluid.heap.FieldValue;
 import org.graalvm.visualvm.lib.jfluid.heap.Heap;
@@ -88,7 +88,7 @@ final class RObjectProperties {
         }
 
         @Override
-        protected Collection<FieldValue> getPropertyItems(RObject object, Heap heap) {
+        protected Collection<FieldValue> getPropertyItems(RObject object) {
             DynamicObject attributes = object.getAttributes();
             if (attributes == null) return null;
 
@@ -105,7 +105,8 @@ final class RObjectProperties {
             String className = instance.getJavaClass().getName();
 
             if (className.startsWith("java.lang.") || // NOI18N
-                className.startsWith("java.math.")) // NOI18N
+                className.startsWith("java.math.") ||  // NOI18N
+                className.startsWith("com.oracle.truffle.api.strings."))    // NOI18N
                 return true;
 
             return false;
@@ -156,7 +157,7 @@ final class RObjectProperties {
         }
 
         @Override
-        protected Collection<FieldValue> getPropertyItems(RObject object, Heap heap) {
+        protected Collection<FieldValue> getPropertyItems(RObject object) {
             List<FieldValue> fields = object.getFieldValues();
             if (fields.isEmpty()) {
                 TruffleFrame frame = object.getFrame();
@@ -231,8 +232,8 @@ final class RObjectProperties {
         }
 
         @Override
-        protected Collection<FieldValue> getPropertyItems(RObject object, Heap heap) throws InterruptedException {
-            HeapOperations.initializeReferences(heap);
+        protected Collection<FieldValue> getPropertyItems(RObject object) throws InterruptedException {
+            HeapOperations.initializeReferences(object.getInstance().getJavaClass().getHeap());
             return object.getReferences();
         }
 
