@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -83,6 +83,11 @@ public class InstanceNode extends HeapViewerNode {
         return instance;
     }
     
+    public int getGCRoots() {
+        Heap heap = instance.getJavaClass().getHeap();
+        return heap.getGCRoots(instance).size();
+    }
+
     public JavaClass getJavaClass() {
         return instance.getJavaClass();
     }
@@ -173,6 +178,7 @@ public class InstanceNode extends HeapViewerNode {
         if (type == DataType.CLASS) return getJavaClass();
         
         if (type == DataType.LOGICAL_VALUE) return getLogicalValue();
+        if (type == DataType.GCROOTS) return getGCRoots();
         
         if (type == DataType.OBJECT_ID) {
             Instance i = getInstance();
@@ -214,6 +220,11 @@ public class InstanceNode extends HeapViewerNode {
             else return super.getName();
         }
 
+        public int getGCRoots() {
+            if (getInstance() == null) return DataType.GCROOTS.getNoValue();
+            else return super.getGCRoots();
+        }
+
         public String getLogicalValue() {
             if (getInstance() == null) return DataType.LOGICAL_VALUE.getNoValue();
             else return super.getLogicalValue();
