@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -66,9 +66,14 @@ import org.openide.util.NbBundle;
 class JavaThreadsProvider {
     
     private static final String OPEN_THREADS_URL = "file:/stackframe/";     // NOI18N
-    
+    private static final String LOCAL_VARIABLE = Bundle.JavaThreadsProvider_LocalVariable();
+    private static final String JNI_LOCAL = Bundle.JavaThreadsProvider_JniLocal();
+
     
     static String getThreadName(Instance instance) {
+        if (isVirtualThread(instance)) {
+            return "Virtual Thread "+DetailsSupport.getDetailsString(instance); // NOI18N
+        }
         String threadName = getThreadInstanceName(instance);
         Long threadId = (Long)instance.getValueOfField("tid");    // NOI18N
         Boolean daemon = (Boolean)instance.getValueOfField("daemon"); // NOI18N
@@ -166,9 +171,9 @@ class JavaThreadsProvider {
                                         if (localInstance != null) {
                                             String text = "";
                                             if (GCRoot.JAVA_FRAME.equals(local.getKind())) {
-                                                text = Bundle.JavaThreadsProvider_LocalVariable();
+                                                text = LOCAL_VARIABLE;
                                             } else if (GCRoot.JNI_LOCAL.equals(local.getKind())) {
-                                                text = Bundle.JavaThreadsProvider_JniLocal();
+                                                text = JNI_LOCAL;
                                             }
                                             localVariableNodes.add(new LocalObjectNode(localInstance, text));
                                         } else {
@@ -261,9 +266,9 @@ class JavaThreadsProvider {
                                         if (localInstance != null) {
                                             String text = "";
                                             if (GCRoot.JAVA_FRAME.equals(local.getKind())) {
-                                                text = Bundle.JavaThreadsProvider_LocalVariable();
+                                                text = LOCAL_VARIABLE;
                                             } else if (GCRoot.JNI_LOCAL.equals(local.getKind())) {
-                                                text = Bundle.JavaThreadsProvider_JniLocal();
+                                                text = JNI_LOCAL;
                                             }
                                             sb.append("       <span class=\"g\">" + text + ":</span> ").append(HeapUtils.instanceToHtml(localInstance, false, javaClassClass)).append("<br>"); // NOI18N
                                         } else {
@@ -298,6 +303,18 @@ class JavaThreadsProvider {
         return DetailsSupport.getDetailsString((Instance)threadName);
     }
     
+    private static boolean isVirtualThread(Instance threadInstance) {
+        JavaClass threadClass = threadInstance.getJavaClass();
+        Heap h = threadClass.getHeap();
+        JavaClass vtClass = h.getJavaClassByName("java.lang.VirtualThread");    // NOI18N
+        if (vtClass != null) {
+            for (;threadClass != null; threadClass = threadClass.getSuperClass()) {
+                if (threadClass.equals(vtClass)) return true;
+            }
+        }
+        return false;
+    }
+
     private static Map<ThreadObjectGCRoot,Map<Integer,List<GCRoot>>> computeJavaFrameMap(Collection<GCRoot> roots) {
         Map<ThreadObjectGCRoot,Map<Integer,List<GCRoot>>> javaFrameMap = new HashMap();
         
