@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,21 +25,6 @@
 
 package org.graalvm.visualvm.jmx.impl;
 
-import org.graalvm.visualvm.jmx.CredentialsProvider;
-import org.graalvm.visualvm.jmx.EnvironmentProvider;
-import org.graalvm.visualvm.application.type.ApplicationType;
-import org.graalvm.visualvm.core.datasource.DataSourceRepository;
-import org.graalvm.visualvm.core.datasource.Storage;
-import org.graalvm.visualvm.core.datasupport.DataChangeEvent;
-import org.graalvm.visualvm.host.Host;
-import org.graalvm.visualvm.host.HostsSupport;
-import org.graalvm.visualvm.core.datasource.descriptor.DataSourceDescriptor;
-import org.graalvm.visualvm.core.datasource.descriptor.DataSourceDescriptorFactory;
-import org.graalvm.visualvm.core.datasupport.DataChangeListener;
-import org.graalvm.visualvm.core.datasupport.Utils;
-import org.graalvm.visualvm.core.options.GlobalPreferences;
-import org.graalvm.visualvm.jmx.JmxApplicationException;
-import org.graalvm.visualvm.jmx.JmxApplicationsSupport;
 import java.awt.BorderLayout;
 import java.io.File;
 import java.io.FilenameFilter;
@@ -63,7 +48,22 @@ import javax.swing.JLabel;
 import javax.swing.JList;
 import javax.swing.JPanel;
 import javax.swing.JScrollPane;
+import org.graalvm.visualvm.application.type.ApplicationType;
 import org.graalvm.visualvm.core.VisualVM;
+import org.graalvm.visualvm.core.datasource.DataSourceRepository;
+import org.graalvm.visualvm.core.datasource.Storage;
+import org.graalvm.visualvm.core.datasource.descriptor.DataSourceDescriptor;
+import org.graalvm.visualvm.core.datasource.descriptor.DataSourceDescriptorFactory;
+import org.graalvm.visualvm.core.datasupport.DataChangeEvent;
+import org.graalvm.visualvm.core.datasupport.DataChangeListener;
+import org.graalvm.visualvm.core.datasupport.Utils;
+import org.graalvm.visualvm.core.options.GlobalPreferences;
+import org.graalvm.visualvm.host.Host;
+import org.graalvm.visualvm.host.HostsSupport;
+import org.graalvm.visualvm.jmx.CredentialsProvider;
+import org.graalvm.visualvm.jmx.EnvironmentProvider;
+import org.graalvm.visualvm.jmx.JmxApplicationException;
+import org.graalvm.visualvm.jmx.JmxApplicationsSupport;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.awt.Mnemonics;
@@ -98,7 +98,7 @@ public class JmxApplicationProvider {
                                                 CURRENT_SNAPSHOT_VERSION_MINOR;
     
     public static final String PROPERTY_RETRY_WITHOUT_SSL = "prop_retry_without_ssl"; // NOI18N
-    private static final String PROPERTY_CONNECTION_STRING = "prop_conn_string";    // NOI18N
+    static final String PROPERTY_CONNECTION_STRING = "prop_conn_string";    // NOI18N
     private static final String PROPERTY_HOSTNAME = "prop_conn_hostname";   // NOI18N
     private static final String PROPERTY_ENV_PROVIDER_ID = "prop_env_provider_id"; // NOI18N
     
