@@ -30,9 +30,11 @@
 #include <windows.h>
 #include <cstddef>
 #include "cmdargs.h"
+#include "jvmfinder.h"
 
 class VisualVMLauncher {
 protected:
+    static const char *REQ_JAVA_VERSION;
     static const char *NBEXEC_FILE_PATH;
     static const char *OPT_VISUALVM_DEFAULT_USER_DIR;
     static const char *OPT_VISUALVM_DEFAULT_CACHE_DIR;
@@ -67,7 +69,7 @@ protected:
     virtual bool initBaseNames();
     virtual void addSpecificOptions(CmdArgs &args);
     virtual bool areWeOn32bits();
-    virtual void adjustHeapAndPermGenSize();
+    virtual void adjustHeapSize();
     virtual bool findUserDir(const char *str);
     virtual bool findCacheDir(const char *str);
     virtual const char * getAppName();
@@ -102,9 +104,11 @@ protected:
     std::string extraClusters;
     std::string nbOptions;
     std::string jdkHome;
+    bool jdkOptionFound;
     
 private:
     bool customUserDirFound;
+    JvmFinder jvmFinder;
 };
 
 #endif	/* _NBLAUNCHER_H */
