@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -90,6 +90,9 @@ public interface CommonConstants {
     public static final int JDK_170 = 15;
     public static final int JDK_180 = 16;
     public static final int JDK_190 = 17;
+    public static final int JDK_200 = 18;
+    public static final int JDK_210 = 19;
+    public static final int JDK_220 = 20;
     public static final int JDK_CVM = 5;
     public static final int JDK_UNSUPPORTED = -1;
 
@@ -109,6 +112,9 @@ public interface CommonConstants {
     public static final String JDK_170_STRING = "jdk170"; // NOI18N
     public static final String JDK_180_STRING = "jdk180"; // NOI18N
     public static final String JDK_190_STRING = "jdk190"; // NOI18N
+    public static final String JDK_200_STRING = "jdk200"; // NOI18N
+    public static final String JDK_210_STRING = "jdk210"; // NOI18N
+    public static final String JDK_220_STRING = "jdk220"; // NOI18N
     public static final String JDK_CVM_STRING = "cvm";  // NOI18N
     public static final String JDK_UNSUPPORTED_STRING = "UNSUPPORTED_JDK"; // NOI18N
 
@@ -118,6 +124,10 @@ public interface CommonConstants {
 
     /** Size of the event buffer, used to store/read rough profiling data */
     public static final int EVENT_BUFFER_SIZE_IN_BYTES = 1200000;
+    /** Default for max string size (in chars) sent as value of parameter from TA */
+    public static final int MAX_STRING_LENGTH_DEFAULT = 1024;
+    /** Max limit for MAX_STRING_LENGTH_DEFAULT */
+    public static final int MAX_STRING_LENGTH_TOP_LIMIT = 4200;
 
     // Codes of various profiling events, that are generated and stored in the buffer file by server and
     // then retrieved by tool
@@ -239,8 +249,8 @@ public interface CommonConstants {
     // we switch to JVMTI in JDK 5.0
     public static final byte THREAD_STATUS_UNKNOWN = -1; // Thread status is unknown.
     public static final byte THREAD_STATUS_ZOMBIE = 0; // Thread is waiting to die. Also used for "doesn't exist yet" and "dead"
-    public static final byte THREAD_STATUS_RUNNING = 1; // Thread is runnable. Note that we unfortunately don't know whether it'
-                                                        // s actually running or pre-empted by another thread...
+    public static final byte THREAD_STATUS_RUNNING = 1; // Thread is runnable. Note that we unfortunately don't know whether it is
+                                                        // actually running or pre-empted by another thread...
     public static final byte THREAD_STATUS_SLEEPING = 2; // Thread is sleeping - Thread.sleep() or JVM_Sleep() was called
     public static final byte THREAD_STATUS_MONITOR = 3; // Thread is waiting on a java monitor
     public static final byte THREAD_STATUS_WAIT = 4; // Thread is waiting - Object.wait() or JVM_MonitorWait() was called
@@ -315,5 +325,6 @@ public interface CommonConstants {
     public static final int AGENT_VERSION_90 = 18;
     public static final int AGENT_VERSION_VISUALVM_20 = 19;
     public static final int AGENT_VERSION_VISUALVM_206 = 20;
-    public static final int CURRENT_AGENT_VERSION = AGENT_VERSION_VISUALVM_206;
+    public static final int AGENT_VERSION_VISUALVM_218 = 21;
+    public static final int CURRENT_AGENT_VERSION = AGENT_VERSION_VISUALVM_218;
 }
