@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,18 +25,6 @@
 
 package org.graalvm.visualvm.lib.jfluid.tests.jfluid;
 
-import org.netbeans.junit.NbTestCase;
-import org.netbeans.junit.diff.LineDiff;
-import org.graalvm.visualvm.lib.jfluid.ProfilerEngineSettings;
-import org.graalvm.visualvm.lib.jfluid.TargetAppRunner;
-import org.graalvm.visualvm.lib.jfluid.classfile.ClassRepository;
-import org.graalvm.visualvm.lib.jfluid.client.AppStatusHandler;
-import org.graalvm.visualvm.lib.jfluid.client.ClientUtils;
-import org.graalvm.visualvm.lib.jfluid.client.ClientUtils.SourceCodeSelection;
-import org.graalvm.visualvm.lib.jfluid.global.CommonConstants;
-import org.graalvm.visualvm.lib.jfluid.global.Platform;
-import org.graalvm.visualvm.lib.jfluid.tests.jfluid.utils.DumpStream;
-import org.graalvm.visualvm.lib.jfluid.utils.MiscUtils;
 import java.io.File;
 import java.io.FileOutputStream;
 import java.io.IOException;
@@ -44,7 +32,19 @@ import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
+import org.graalvm.visualvm.lib.jfluid.ProfilerEngineSettings;
+import org.graalvm.visualvm.lib.jfluid.TargetAppRunner;
+import org.graalvm.visualvm.lib.jfluid.client.AppStatusHandler;
+import org.graalvm.visualvm.lib.jfluid.client.ClientUtils;
+import org.graalvm.visualvm.lib.jfluid.client.ClientUtils.SourceCodeSelection;
 import org.graalvm.visualvm.lib.jfluid.filters.InstrumentationFilter;
+import org.graalvm.visualvm.lib.jfluid.global.CommonConstants;
+import org.graalvm.visualvm.lib.jfluid.global.Platform;
+import org.graalvm.visualvm.lib.jfluid.tests.jfluid.utils.DumpStream;
+import org.graalvm.visualvm.lib.jfluid.utils.MiscUtils;
+import org.netbeans.junit.NbTestCase;
+import org.netbeans.junit.diff.LineDiff;
+import org.openide.modules.InstalledFileLocator;
 
 
 public abstract class CommonProfilerTestCase extends NbTestCase {
@@ -309,7 +309,7 @@ public abstract class CommonProfilerTestCase extends NbTestCase {
         //coverage
         //settings.setMainClassPath("/space/tmp/testrun/emma/lib/emma.jar:" + xData + jarPath);
         settings.setMainClass(getMainClass());
-        ClassRepository.initClassPaths(getDataDir().getAbsolutePath(), new String[] { projPath, "", "" });
+        settings.setVMClassPaths(projPath, "", "");
     }
 
     protected PrintStream getLogStream() {
@@ -323,18 +323,29 @@ public abstract class CommonProfilerTestCase extends NbTestCase {
     protected void setProfilerHome(ProfilerEngineSettings settings) {
         try {
             String profilerHome = System.getProperty("profiler.home");
-
+            String libsDir;
             if ((profilerHome == null) || !new File(profilerHome).exists()) {
-                profilerHome = System.getProperty("netbeans.home").replace("platform", "profiler");
+                libsDir = getLibsDir();
+            } else {
+                libsDir = profilerHome + "/lib";
             }
 
-            settings.initialize(profilerHome + "/lib");
+            settings.initialize(libsDir);
         } catch (IOException ex) {
             ex.printStackTrace();
             assertFalse("Error in initialization", true);
         }
     }
 
+    private String getLibsDir() {
+        final File dir = InstalledFileLocator.getDefault().locate("lib/jfluid-server.jar", //NOI18N
+                                                     "org.graalvm.visualvm.lib.jfluid", false); //NOI18N
+        if (dir == null) {
+            return null;
+        }
+        return dir.getParentFile().getPath();
+    }
+
     protected String getProjectPath(String projectName) {
         String jarPath = "/projects/" + projectName + "/distrib/" + projectName + ".jar";
 
