@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -93,7 +93,7 @@ public class BasicAttachStepsProvider extends AttachStepsProvider {
     protected String currentARCH = LINK_64ARCH;
     
     
-    private final Set<ChangeListener> listeners = new HashSet();
+    private final Set<ChangeListener> listeners = new HashSet<>();
     
     public synchronized final void addChangeListener(ChangeListener listener) {
         listeners.add(listener);
