@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,6 +24,7 @@
  */
 package org.graalvm.visualvm.lib.profiler.heapwalk.details.jdk;
 
+import java.time.Instant;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
@@ -225,6 +226,7 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
     
     @NbBundle.Messages({
         "UtilDetailsProvider_OneItemString=1 element",                          // NOI18N
+        "# {0} - number of elements",                                           // NOI18N
         "UtilDetailsProvider_ItemsNumberString={0} elements"                    // NOI18N
     })
     private static String getElementsString(int length) {
@@ -264,11 +266,7 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
 
         @Override
         public long getMillis() {
-            Object time = record.getValueOfField("millis");
-            if (time instanceof Number) {
-                return ((Number)time).longValue();
-            }
-            return 0;
+            return getInstant().toEpochMilli();
         }
 
         @Override
@@ -291,11 +289,24 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
             return DetailsUtils.getInstanceFieldString(record, "message");    // NOI18N
         }
 
+        // @Override since JDK 9
+        public Instant getInstant() {
+            Object instant = record.getValueOfField("instant");     // NOI18N
+            if (instant instanceof Instance) {
+                return TimeDetailsProvider.getInstant(instant);
+            }
+            Object time = record.getValueOfField("millis");
+            if (time instanceof Number) {
+                return Instant.ofEpochMilli(((Number)time).longValue());
+            }
+            return Instant.EPOCH;
+        }
+
         @Override
         public Object[] getParameters() {
             Object pars = record.getValueOfField("parameters");
             if (pars instanceof ObjectArrayInstance) {
-                List parameters = new ArrayList();
+                List<String> parameters = new ArrayList<>();
 
                 for (Instance o : ((ObjectArrayInstance)pars).getValues()) {
                     String par = null;
@@ -313,7 +324,21 @@ public final class UtilDetailsProvider extends DetailsProvider.Basic {
         @Override
         public Level getLevel() {
             String level = DetailsUtils.getInstanceFieldString(record, "level");  // NOI18N
-            return Level.parse(level);
+            try {
+                return Level.parse(level);
+            } catch (RuntimeException ex) {
+                // custom level, construct level directly
+                Instance levelObj = (Instance)record.getValueOfField("level");  // NOI18N
+                Integer value = (Integer)levelObj.getValueOfField("value");     // NOI18N
+                if (level == null) level = "NULL";        // NOI18N
+                return new CustomLevel(level, value);     // NOI18N
+            }
+        }
+    }
+
+    private static class CustomLevel extends Level {
+        private CustomLevel(String name, int value) {
+            super(name, value);
         }
     }
 }
