@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -626,7 +626,7 @@ public class OQLEngineTest {
             }
         });
 
-        assertEquals(Double.class, rsltClass[0]);
+        assertTrue(Number.class.isAssignableFrom(rsltClass[0]));
     }
 
     @Test
@@ -683,11 +683,11 @@ public class OQLEngineTest {
 
             public boolean visit(Object o) {
                 System.out.println(o);
-                rslt[0] = o.toString();
+                rslt[0] = dump(o);
                 return true;
             }
         });
-        assertEquals("{value=, key=sun.cpu.isalist}", rslt[0]);
+        assertEquals("{key=sun.cpu.isalist, value=}", rslt[0]);
     }
 
     @Test
@@ -745,4 +745,17 @@ public class OQLEngineTest {
             }
         });
     }
+
+    private String dump(Object o) {
+        if (o instanceof Map) {
+            List<String> els = new ArrayList<>();
+            Map<?,?> m = (Map) o;
+            for (Map.Entry e : m.entrySet()) {
+                els.add(e.getKey()+"="+e.getValue());
+            }
+            els.sort(null);
+            return "{"+String.join(", ", els)+"}";
+        }
+        return o.toString();
+    }
 }
